@@ -15,11 +15,12 @@
 #' str_singleize("abababcabab", "ab")
 #' str_singleize(c("abab", "cdcd"), "cd")
 #' str_singleize(c("abab", "cdcd"), c("ab", "cd"))
-#'
 #' @family removers
 #' @export
 str_singleize <- function(string, pattern) {
-  if (is_l0_char(string)) return(character())
+  if (is_l0_char(string)) {
+    return(character())
+  }
   verify_string_pattern(string, pattern)
   dup_patt <- str_c("(", pattern, ")+")
   str_replace_all(string, dup_patt, pattern)
